@@ -177,21 +177,36 @@ class ImageRecognition(object):
             
             depth = out.get_shape().as_list()[-1]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
-            out = new_fc_layer(out, 
-                                num_inputs = depth, 
-                                num_outputs = len(self.classes), 
-                                name = 'fc1', 
-                                dropout_val=1, 
-                                activation="NONE",
-                                lrelu_alpha=0.2, 
-                                data_type=tf.float32,
-                                is_training=is_training,
-                                use_bias=False)
 
-            if len(self.classes) == 1:
-                out = tf.nn.sigmoid(out)
-            else:
-                out = tf.nn.softmax(out)
+            if self.classification_by_regression:
+                out = new_fc_layer(out, 
+                                    num_inputs = depth, 
+                                    num_outputs = 1, 
+                                    name = 'fc1', 
+                                    dropout_val=1, 
+                                    activation="NONE",
+                                    lrelu_alpha=0.2, 
+                                    data_type=tf.float32,
+                                    is_training=is_training,
+                                    use_bias=False)
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+            
+            else: 
+                out = new_fc_layer(out, 
+                                    num_inputs = depth, 
+                                    num_outputs = len(self.classes), 
+                                    name = 'fc1', 
+                                    dropout_val=1, 
+                                    activation="NONE",
+                                    lrelu_alpha=0.2, 
+                                    data_type=tf.float32,
+                                    is_training=is_training,
+                                    use_bias=False)
+
+                if len(self.classes) == 1:
+                    out = tf.nn.sigmoid(out)
+                else:
+                    out = tf.nn.softmax(out)
             
             self.out = out
         return out, base_var_list
@@ -278,17 +293,19 @@ class ImageRecognition(object):
 
     def __prepare_output_val(self, index=None, key=None):
         if self.classification_by_regression: 
-            try: 
-                if key in self.regression_value:
-                    regression_val = [self.regression_value[key]]
-                else: 
-                    regression_val = [1.0]
+            if key in self.regression_value:
+                regression_val = [self.regression_value[key]]
                 return regression_val, False
-                
-            except: 
-                print("Key {} not found in json regression label".format(key))
-                regression_val = None 
-                return regression_val, True
+
+            else: 
+                if index == 1:
+                    regression_val = [1.0]
+                    return regression_val, False
+
+                else: 
+                    print("Key {} not found in json regression label".format(key))
+                    regression_val = None
+                    return regression_val, True
 
         else: 
             tmp_y = np.zeros((len(self.classes))).astype(np.float32)
